@@ -7,6 +7,7 @@ KEY__configuration_description = "configuration_description"
 KEY__exception = "exception"
 KEY__install_key = "install_key"
 KEY__deletion_key = "deletion_key"
+KEY__superjaaql_password = "superjaaql_password"
 KEY__records_total = "records_total"
 KEY__records_filtered = "records_filtered"
 KEY__data = "data"
@@ -20,6 +21,12 @@ KEY__parameter_name = "parameter_name"
 KEY__parameter_description = "parameter_description"
 KEY__size = "size"
 KEY__database = "database"
+KEY__authorization = "authorization"
+KEY__argument = "argument"
+KEY__is_node = "is_node"
+KEY__connection = "connection"
+KEY__node = "node"
+KEY__application_url = "url"
 KEY__role = "role"
 KEY__mfa_key = "mfa_key"
 KEY__username = "username"
@@ -30,12 +37,18 @@ KEY__page = "page"
 KEY__show_deleted = "show_deleted"
 KEY__description = "description"
 KEY__database_name = "name"
+KEY__node_name = "name"
 KEY__port = "port"
 KEY__address = "address"
 KEY__jaaql_name = "jaaql_name"
 KEY__otp_uri = "otp_uri"
 KEY__otp_qr = "otp_qr"
 KEY__user_agent = "user_agent"
+KEY__jaaql_otp_uri = "jaaql_otp_uri"
+KEY__jaaql_otp_qr = "jaaql_otp_qr"
+KEY__superjaaql_otp_uri = "superjaaql_otp_uri"
+KEY__superjaaql_otp_qr = "superjaaql_otp_qr"
+
 ATTR__deleted = "deleted"
 
 HEADER__security = "Authentication-Token"
@@ -67,4 +80,4 @@ JAAQL__arg_marker = ":"
 ENCODING__utf = "UTF-8"
 EXAMPLE__jwt = "eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzI1NiJ9.e30.yXvILkvUUCBqAFlAv6wQ1Q-QRAjfe3eSosO949U73Vo"
 
-VERSION = "1.2.11"
+VERSION = "2.0.0"
