@@ -1,4 +1,5 @@
 from jaaql.exceptions.http_status_exception import *
+from datetime import datetime
 import re
 from jaaql.db.db_interface import DBInterface, ECHO__none
 
@@ -123,6 +124,8 @@ class InterpretJAAQL:
 
             past_parameters = {}
 
+            conn.set_session(autocommit=len(operation) != 1)
+
             for query, parameters, echo, cur_assert in zip(query_list, parameters_list, echo_list, assert_list):
                 last_echo = echo
                 last_query = query
@@ -210,6 +213,8 @@ class InterpretJAAQL:
             return PYFORMAT_str
         elif isinstance(value, float):
             return PYFORMAT_str
+        elif isinstance(value, datetime):
+            return PYFORMAT_str
         else:
             raise HttpStatusException(ERR_mistyped_parameter % (type(value).__name__, key), HTTPStatus.BAD_REQUEST)
 
